@@ -1,8 +1,8 @@
 # coding=utf-8
 import json
-import re
 from datetime import datetime
-
+import six
+import re
 from tornkts.base.server_response import ServerError
 
 
@@ -15,6 +15,8 @@ class ArgumentsMixin(object):
 
     MIN_DATE = datetime.strptime('1900-01-01', '%Y-%m-%d')
 
+    STR_TYPE = unicode if six.PY2 else str
+
     def _clear_kwargs(self, kwargs):
         return dict((k, v) for k, v in kwargs.items() if k in ['default', 'strip'])
 
@@ -156,7 +158,7 @@ class ArgumentsMixin(object):
         argument = self.get_argument(name, **self._clear_kwargs(kwargs))
         try:
             if argument != kwargs.get('default'):
-                argument = unicode(argument)
+                argument = self.STR_TYPE(argument)
             else:
                 return argument
         except Exception:
@@ -199,7 +201,12 @@ class ArgumentsMixin(object):
                                       field=name,
                                       field_problem=ServerError.FIELD_NOT_ALLOWED)
 
+        if kwargs.get('none_if_empty', False) is True:
+            if len(argument) == 0:
+                argument = None
+
         check()
+
         if kwargs.get('clear_regexp', None) is not None:
             clear_regexp = kwargs.get('clear_regexp')
             argument = re.sub(clear_regexp, '', argument)
@@ -216,7 +223,7 @@ class ArgumentsMixin(object):
         arguments = self.get_argument(name, **self._clear_kwargs(kwargs))
         try:
             if arguments != kwargs.get('default'):
-                arguments = [str(x) for x in arguments.split(',')]
+                arguments = [self.STR_TYPE(x) for x in arguments.split(',')]
             else:
                 return arguments
         except Exception:
